@@ -2,7 +2,7 @@
 
 package Dancer::Plugin::Authorize::Credentials::Config;
 BEGIN {
-  $Dancer::Plugin::Authorize::Credentials::Config::VERSION = '0.04';
+  $Dancer::Plugin::Authorize::Credentials::Config::VERSION = '0.10';
 }
 
 use strict;
@@ -87,34 +87,20 @@ Dancer::Plugin::Authorize::Credentials::Config - Dancer::Plugin::Authorize authe
 
 =head1 VERSION
 
-version 0.04
+version 0.10
 
 =head1 SYNOPSIS
 
-    plugins:
-      Authorize:
-        mykeyword: 
-          credentials:
-            class: Config
-            options: 
-              accounts:
-                user01:
-                  name: Joe Schmoe
-                  password: foobar
-                  roles:
-                    - guest
-                    - user
-                user02:
-                  name: Jacque Fock
-                  password: barbaz
-                  roles:
-                    - admin
-                    
-    # in Dancer application
+    # in your app code
+    my $auth = auth($login, $password);
+    if ($auth) {
+        # login successful
+    }
     
-    if (mykeyword()) {
-        # authenticated
-        return 1;
+    # use your own encryption (if the user account password is encrypted)
+    my $auth = auth($login, encrypt($password));
+    if ($auth) {
+        # login successful
     }
 
 =head1 DESCRIPTION
@@ -122,8 +108,6 @@ version 0.04
 Dancer::Plugin::Authorize::Credentials::Config uses your Dancer application
 configuration file as the application's user management system.
 
-** Note! This authentication class sets the user's roles automatically. **
-
 =head1 METHODS
 
 =head2 authorize
@@ -131,11 +115,31 @@ configuration file as the application's user management system.
 The authorize method (found in every authentication class) validates a user against
 the defined datastore using the supplied arguments and configuration file options.
 
+=head1 CONFIGURATION
+
+    plugins:
+      Authorize:
+        credentials:
+          class: Config
+          options: 
+            accounts:
+              user01:
+                name: Joe Schmoe
+                password: foobar
+                roles:
+                  - guest
+                  - user
+              user02:
+                name: Jacque Fock
+                password: barbaz
+                roles:
+                  - admin
+
 =head1 METHODS
 
 =head1 AUTHOR
 
-Al Newkirk <awncorp@cpan.org>
+  Al Newkirk <awncorp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
