@@ -2,7 +2,7 @@
 
 package Dancer::Plugin::Authorize::Permissions::Config;
 BEGIN {
-  $Dancer::Plugin::Authorize::Permissions::Config::VERSION = '0.04';
+  $Dancer::Plugin::Authorize::Permissions::Config::VERSION = '0.10';
 }
 
 use strict;
@@ -41,15 +41,22 @@ sub subject_can {
             my $permissions = $roles->{$role}->{permissions};
             if (defined $permissions->{$operation}) {
                 
-                if (defined $permissions->{$operation}->{operations}) {
-                    
-                    my $operations = $permissions->{$operation}->{operations};
-                    if (grep { /$action/ } @{$operations}) {
+                if ($action) {
+
+                    if (defined $permissions->{$operation}->{operations}) {
                         
-                        return 1;
+                        my $operations = $permissions->{$operation}->{operations};
+                        if (grep { /$action/ } @{$operations}) {
+                            
+                            return 1;
+                            
+                        }
                         
                     }
-                    
+
+                }
+                else {
+                    return 1;
                 }
                 
             }
@@ -71,43 +78,35 @@ Dancer::Plugin::Authorize::Permissions::Config - Dancer::Plugin::Authorize acces
 
 =head1 VERSION
 
-version 0.04
+version 0.10
 
 =head1 SYNOPSIS
 
     plugins:
       Authorize:
-        mykeyword: 
-          permissions:
-            class: Config
-            options: 
-              control:
-                admin:
-                  permissions:
-                    manage accounts:
-                      operations:
-                        - view
-                        - create
-                        - update
-                        - delete
-                user:
-                  permissions:
-                    manage accounts:
-                      operations:
-                        - view
-                        - create
-                guests:
-                  permissions:
-                    manage accounts:
-                      operations:
-                        - view
-                        
-    # in Dancer application
-    
-    my $role = 'guests';
-    if (mykeyword_asa($role)) {
-        return 1;
-    }
+        permissions:
+          class: Config
+          options: 
+            control:
+              admin:
+                permissions:
+                  manage accounts:
+                    operations:
+                      - view
+                      - create
+                      - update
+                      - delete
+              user:
+                permissions:
+                  manage accounts:
+                    operations:
+                      - view
+                      - create
+              guests:
+                permissions:
+                  manage accounts:
+                    operations:
+                      - view
 
 =head1 DESCRIPTION
 
@@ -135,7 +134,7 @@ perform the specified action under that operation.
 
 =head1 AUTHOR
 
-Al Newkirk <awncorp@cpan.org>
+  Al Newkirk <awncorp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
